<?php

require_once "config/config.php";
session_name(SESSIONNAME); //set the session name
session_start(); //start up the session (or resume a previous one)



/*****************************************************************
 * ***************** BASIC FUNCTIONS *****************************
 * ***************************************************************/
//check for page validity
function isvalidpage($page){
    if(file_exists("pages/$page.php") ){
	return true;
    }else{
	return false;
    }
}

//check for subpage validity
function isvalidsubpage($subpage){
    if(file_exists("pages/subpages/$subpage.php")){
	return true;
    }else{
	return false;
    }
}

//print out nav bar items
function printtopnav(){
   echo <<<CODE
   <ul>
    <li><a href="?page=controlpanel">Control Panel</a></li>
    <li><a href="?page=manageactors">Manage Actors</a></li>
    <li><a href="?page=manageshows">Manage Shows</a></li>
	<li><a href="?page=manageschedule">Manage Schedule</a></li>
    </ul>
CODE;
}

//print out subnav items (context nav)
function printsubnav($page){
    //check that the requested page is valid
    if(!isvalidpage($page)){
	$page=DEFAULTPAGE;
    }

    switch($page){
	case "manageshows":
	    echo <<<CODE
<ul>
<li><a href="?page=manageshows&subpage=addshow">Add Show</a></li>
<li><a href="?page=manageshows&subpage=modshow">Modify Show</a></li>
<li><a href="?page=manageshows&subpage=delshow">Delete Show</a></li>
</ul>
CODE;
	    break;
	case "manageactors":
	    echo <<<CODE
<ul>
<li><a href="?page=manageactors&subpage=addactor">Add Actor</a></li>
<li><a href="?page=manageactors&subpage=modactor">Modify Actor</a></li>
<li><a href="?page=manageactors&subpage=delactor">Delete Actor</a></li>
</ul>
CODE;
		break;
	case "manageschedule":
		echo <<<CODE
<ul>
	<li>Scheduling Wizard</li>
	<li><a href="?page=manageschedule&subpage=addmanualappt">Add Manual Appointment</a></li>
	<li><a href="?page=manageschedule&subpage=delappt">Delete Appointment(s)</a></li>
	<li><a href="?page=manageschedule&subpage=shopschedule">Shop Schedule</a></li>
</li>
CODE;
		break;
	default:
	    echo "&nbsp;";
	    break;
    }
}





/* **********************************************************************
 * *****************  DATABASE FUNCTIONS  *******************************
 * *********************************************************************/


/*
  $dbfile = sqlite_open('schedulefit.sqlite',0666);
  if ($dbfile) {
      $result = sqlite_query($dbfile, "SHOW TABLES;");
    sqlite_query($dbfile, "CREATE TABLE users (FirstName CHAR(50), LastName CHAR(50));");
    sqlite_query($dbfile, "INSERT INTO users VALUES ('Nick', 'Veitch')");
    $result = sqlite_query($dbfile, "SELECT FirstName, LastName FROM users");
    var_dump(sqlite_fetch_array($result, SQLITE_ASSOC));
  } else {
    print "Database could not be opened\n";
  }
 * <?php
try {
    $dbh = new PDO('mysql:host=localhost;dbname=test', $user, $pass);
    foreach($dbh->query('SELECT * from FOO') as $row) {
        print_r($row);
    }
    $dbh = null;
} catch (PDOException $e) {
    print "Error!: " . $e->getMessage() . "<br/>";
    die();
}
?>

*/

function dbconnect(){
    $dbhandle = new PDO(DBCONNECTSTRING);
    $dbhandle->query("PRAGMA foreign_keys = on"); //enable foreign key enforcement
    $dbhandle->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION); //force errors to be thrown as exceptions
    return $dbhandle;
}



function dbdisconnect($dbhandle){
    $dbhandle=null; //forgetting the dbhandle disconnects the session
}



function listtables($dbhandle){
    if(error_reporting()==E_ALL){
	echo "listtables called<br />";
    }

    $tablequery=$dbhandle->query('select name from sqlite_master where type=\'table\'
	and name!=\'sqlite_sequence\'');

    $tablelist=$tablequery->fetchAll();
    if(count($tablelist)>0){
	foreach($tablelist as $row){
	    $tables[]=$row['name'];
	}
    }

    return $tables;
}


//drop listed db tables
function droptables($tablelist,$dbhandle){
    $success=true; //success flag


    //declare what's going on
    if(error_reporting()==E_ALL){
	echo "droptables function called<br />";
	echo "list of tables to drop: ";
	print_r($tablelist);
	echo "<br />";
    }

    //make the actual delete happen
    foreach($tablelist as $table){
	//$dropquery=$dbhandle->quote("DROP TABLE $table");
	try{
	    if(error_reporting()==E_ALL){
		echo "dropping table: " . $table . "<br />";
		echo "query: drop table " . $table . "<br />";
	    }
	    $dbhandle->exec("drop table if exists $table");
	}catch(PDOException $error){
	    echo "<div id=\"errmsg\">\n";
	    echo "error: droptables->drop table $table<br />";
	    if(error_reporting()==E_ALL){
		echo $error->getMessage() . "<br />";
		echo "query: drop table $table<br />";
	    }
	    echo "</div>\n";
	    $success=false;
	    break;
	}
    }

    return $success;
}


//initialize table structure in databse
// ERASES ALL EXISTING TABLES!!
function initializedb(){
	$status=true;
    if(error_reporting()==E_ALL){
	echo "initializedb called<br />";
    }

    $dbhandle=dbconnect();
	$maxpriority=MAXPRIORITY;
    $tables=listtables($dbhandle);
    
    if(count($tables)>0){
		if(droptables($tables,$dbhandle)!=true){
			echo "<div id=\"errmsg\">\n";
			echo "error: cannot drop tables<br />";
			if(error_reporting()==E_ALL){
			echo "initializedb->droptables failed<br />\n";
			}
			echo "</div>\n";
		}
    }


    //create shows table
    $dbhandle->exec("create table shows (
	id integer primary key,
	title text unique not null,
	start text not null,
	end text not null,
	max_pri integer default 0 not null,
	check (max_pri >= 0 and max_pri <=$maxpriority)
	)");
	
    //create priority_labels table
    $dbhandle->exec("create table priority_labels (
		showid integer ,
		priority integer not null,
		label string,
		foreign key (showid) references shows(id) on update cascade on delete cascade,
		primary key (showid,priority),
		check (priority <= $maxpriority and priority >=1)
	)");

    //create actors table
    $dbhandle->exec("create table actors (
	id text primary key,
	fname text not null,
	lname text not null,
	phone text,
	staff text not null
	)");

    //create casts table
    $dbhandle->exec("create table casts (
	showid integer not null,
	actorid text not null,
	partname text default null,
	priority integer default 0 not null,
	foreign key (showid) references shows(id) on update cascade on delete cascade,
	foreign key (actorid) references actors(id) on update cascade on delete cascade,
	primary key (showid,actorid)
	)");



	//create availability table
	$dbhandle->exec("create table availability (
		id text,
		time text not null,
		day text not null,
		foreign key (id) references actors(id) on update cascade on delete cascade,
		primary key (id,time,day)
	)");

	//create appointments table
	$dbhandle->exec("create table appointments (
		apptid integer primary key autoincrement,
		actorid text not null,
		showid integer not null,
		start text not null,
		end text not null,
		note text,
		foreign key (actorid) references actors(id) on update cascade on delete cascade,
		foreign key (showid) references shows(id) on update cascade on delete cascade
	)");

	return $status;
}

function getprilabels($showid){
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare('select priority,label from priority_labels
								where showid=:id
								order by priority asc');
	$query->bindParam(':id',$showid);
	$query->execute();
	$result=$query->fetchAll();
	$query->closeCursor();
	dbdisconnect($dbhandle);
	if(count($result)<1){return null;} //avoid bad if an empty set returns
	foreach($result as $row){
		$labels[$row["priority"]]=$row["label"];
	}
	return $labels;
}

function getpeople(){
    $dbhandle=dbconnect();
    $query=$dbhandle->prepare("select * from actors");
    $query->execute();
    $actors=$query->fetchAll();
    $query->closeCursor();
    dbdisconnect($dbhandle);
    return $actors;
}

function getactors(){
    $dbhandle=dbconnect();
    $query=$dbhandle->prepare("select * from actors where staff='false'");
    $query->execute();
    $actors=$query->fetchAll();
    $query->closeCursor();
    dbdisconnect($dbhandle);
    return $actors;
}

function getcast($showid){
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare("
		select * from casts
		join actors
		on casts.actorid=actors.id
		join shows
		on casts.showid=shows.id
		where showid=:showid order by showid,priority");
	$query->bindParam(":showid",$showid);
	$query->execute();
	$cast=$query->fetchAll();
	dbdisconnect($dbhandle);
	return $cast;
}

function getactor($id){
    $dbhandle=dbconnect();
    $query=$dbhandle->prepare('select * from actors where id=:id');
    $query->execute(array($id));
    $result=$query->fetch();
    $query->closeCursor();
    dbdisconnect($dbhandle);
    return $result;
}

function addactor($toadd){
    $dbhandle=dbconnect();
    $query=$dbhandle->prepare('insert into actors
	    (id,fname,lname,phone,staff) values (:id,:fname,:lname,:phone,:staff)');
    foreach($toadd as $actor){
		$query->bindParam(':id',$actor["id"]);
		$query->bindParam(':fname', $actor["fname"]);
		$query->bindParam(':lname', $actor["lname"]);
		$query->bindParam(':staff', $actor["staff"]);
		$query->bindParam(':phone', $actor["phone"]);
		if(strlen($actor["phone"])<4){
			$actor["phone"]=null;
		}
		$success[]=$query->execute();
    }
    $query->closeCursor();
    dbdisconnect($dbhandle);
    foreach($success as $check){
		if(!$check){
			return false;
		}
    }
    return true;
}

function delactor($todel){
    $dbhandle=dbconnect();
	$dbhandle->beginTransaction();
	$query=$dbhandle->prepare('delete from appointments where actorid=:id');
	foreach($todel as $actor){
		$query->bindParam(':id',$actor);
		$success[]=$query->execute();
	}
	$query=$dbhandle->prepare('delete from availability where id=:id');
	foreach($todel as $actor){
		$query->bindParam(':id',$actor);
		$success[]=$query->execute();
	}
	$query=$dbhandle->prepare('delete from casts where actorid=:id');
	foreach($todel as $actor){
		$query->bindParam(':id',$actor);
		$success[]=$query->execute();
	}
    $query=$dbhandle->prepare('delete from actors where id=:id');
    foreach($todel as $actor){
		$query->bindParam(':id',$actor);
		$success[]=$query->execute();
    }
    $query->closeCursor();
    foreach($success as $check){
		if(!$check){
			$dbhandle->rollBack();
			dbdisconnect($dbhandle);
			return $check;
		}
    }
    return $dbhandle->commit();
}

function modactor($tomod){
    $dbhandle=dbconnect();
	$dbhandle->beginTransaction();
	$query=$dbhandle->prepare('update casts set actorid=:id where actorid=:oldid');
	foreach($tomod as $actor){
		$query->bindParam(':id',$actor["id"]);
		$query->bindParam(':oldid',$actor["oldid"]);
		$result[]=$query->execute();
	}
    $query=$dbhandle->prepare('update actors set id=:id,fname=:fname,lname=:lname,phone=:phone,staff=:staff
		where id=:oldid');
    foreach($tomod as $actor){
		$query->bindParam(':id',$actor["id"]);
		$query->bindParam(':fname', $actor["fname"]);
		$query->bindParam(':lname', $actor["lname"]);
		$query->bindParam(':phone', $actor["phone"]);
		$query->bindParam(':oldid', $actor["oldid"]);
		if(!isset($actor["staff"])){
			$actor["staff"]=null;
		}
		if(strlen($actor["phone"])<4){
			$actor["phone"]=null;
		}
		$query->bindParam(':staff', $actor["staff"]);
		$result[]=$query->execute();
    }
    foreach($result as $check){
		if(!$check){
			$dbhandle->rollBack();
			$dbdisconnect($dbhandle);
			return $check;
		}
    }
	return $dbhandle->commit();
}

//addavail expects an array of days, each an array of times, as well as an actor
function addavail($id,$avail){
	$status=true;
	//make sure $id is NOT an array, and $avail and all its elements ARE
	if(is_array($id) || !is_array($avail)){
		$status=false;
	}else{
		foreach($avail as $day){
			if(!is_array($day)){
				$status=false;
			}
		}
	}
	//barf if we got poisonous input
	if(!$status){return $status;}


	$dbhandle=dbconnect();
	//clear out previous availability data
	$addavailquery=$dbhandle->prepare("delete from availability where id=:id");
	$addavailquery->bindParam(":id",$id);
	$addavailquery->execute();

	//add new availability data
	$addavailquery=$dbhandle->prepare("insert into availability (id,time,day) values (:id,:time,:day)");
	$addavailquery->bindParam(":id",$id);
	$currenttime=new DateTime(WEEKSTART . " " . DAYSTART);
	for($i=0;$i<WORKDAYS;$i++){
		$addavailquery->bindParam(":day",$currenttime->format('D'));
		foreach($avail[($currenttime->format('D'))] as $currentavail){
			$addavailquery->bindParam(":time",$currentavail);
			$addavailquery->execute();
		}
		$currenttime->modify("+1 day");
	}

	echo "</p>";
	return $status;
}

function getshows(){
    $dbhandle = dbconnect(); //connect to the db
    $query = $dbhandle->query("select * from shows");
    $result=$query->fetchAll();//pull all the results
    $query->closeCursor();
    dbdisconnect($dbhandle);
    return $result; //send them back to the caller
}


function getshow($id){
    $dbhandle=dbconnect();
    $query=$dbhandle->prepare("select * from shows where id=?");
    $query->execute(array($id));
    $result=$query->fetch();
    $query->closeCursor();
    dbdisconnect($dbhandle);
    return $result;
}

function showstart($value){
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare("select * from shows where :value=start");
	$query->bindParam(":value",$value);
	$query->execute();
	$result=$query->fetchAll();
	dbdisconnect($dbhandle);
	return $result;
}

function showend($value){
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare("select * from shows where :value=end");
	$query->bindParam(":value",$value);
	$query->execute();
	$result=$query->fetchAll();
	dbdisconnect($dbhandle);
	return $result;
}

function getpart($actorid,$showid){
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare("select partname from casts where showid=:showid and actorid=:actorid");
	$query->bindParam(":showid",$showid);
	$query->bindParam(":actorid",$actorid);
	$query->execute();
	$result=$query->fetch();
	return $result;
}

function addshow($toadd){
    $dbhandle=dbconnect(); //connect to db
    $addquery=$dbhandle->prepare("insert into shows (title,start,end)
	values (:title,:start,:end)"); //set up the prepared insert statement
    
    foreach($toadd as $show){//cycle through the array of incoming shows to add
		//bind variables
		$addquery->bindParam(':title',$show["title"]);
		$addquery->bindParam(':start',$show["start"]);
		$addquery->bindParam(':end',$show["end"]);
		//execute the insert, capture the result, append to a result array
		if($addquery->execute()!=1){
			$result[]=getshowbytitle($show["title"]);
		}else{
			$result[]=false;
		}
    }
    return $result; //return the result array. Let the caller act on it.
}

function addcast($showid,$cast){
	$dbhandle=dbconnect();
	$addquery=$dbhandle->prepare("insert into casts (showid, actorid, partname)
		values (:showid, :actorid, :partname)");
	$addquery->bindParam(":showid",$showid);
	foreach($cast as $actor){
		try{
			if(strlen($actor["partname"]) < 1){
				continue;
			}
			$addquery->bindParam(":actorid",$actor["id"]);
			$addquery->bindParam(":showid",$showid);
			$addquery->bindParam(":partname",$actor["partname"]);
			$addquery->execute();
		}catch(PDOException $e){
			var_dump($e);
		}

	}
}

function delcast($showid){
	$dbhandle=dbconnect();
	$delquery=$dbhandle->prepare("delete from casts where showid=:showid");
	$delquery->bindParam(":showid",$showid);
	$result=$delquery->execute();
	dbdisconnect($dbhandle);
	return $result[0];
}

function delcastmember($todel){
	$dbhandle=dbconnect();
	$delquery=$dbhandle->prepare("delete from casts where showid=:showid and actorid=:actorid");
	foreach($todel as $pair){
		$delquery->bindParam(":actorid",$pair["actorid"]);
		$delquery->bindParam(":showid",$pair["showid"]);
		$delquery->execute();
		$delquery->fetchAll();
	}
	dbdisconnect($dbhandle);
}

function modshow($tomod){
    $dbhandle=dbconnect();
	$dbhandle->beginTransaction();
    $modquery=$dbhandle->prepare('update shows set title=:title,start=:start,
	    end=:end,max_pri=:max_pri where id=:id');
    foreach($tomod as $show){
		$modquery->bindParam(':title',$show["title"]);
		$modquery->bindParam(':start', $show["start"]);
		$modquery->bindParam(':end', $show["end"]);
		$modquery->bindParam(':max_pri', $show["max_pri"]);
		$modquery->bindParam('id', $show["id"]);
		$result[]=$modquery->execute();
    }
    dbdisconnect($dbhandle);
    return $result;
}

function delappt($todel){
	if(!is_array($todel)){
		return false;
	}
	$dbhandle=dbconnect();
	$deleted=0;
	$query=$dbhandle->prepare("delete from appointments where apptid=:apptid");
	foreach($todel as $appt){
		$query->bindParam(":apptid",$appt);
		$deleted+=$query->execute();
	}
	dbdisconnect($dbhandle);
	return $deleted;
}

function delshow($todel){
    $dbhandle=dbconnect();
	$dbhandle->beginTransaction();
	$delquery=$dbhandle->prepare("delete from priority_labels where showid=:id");
	foreach($todel as $show){
		$delquery->bindParam(":id",$show);
		$result[]=$delquery->execute();
	}
	$delquery=$dbhandle->prepare("delete from appointments where showid=:id");
	foreach($todel as $show){
		$delquery->bindParam(":id",$show);
		$result[]=$delquery->execute();
	}
	$delquery=$dbhandle->prepare("delete from casts where showid=:id");
	foreach($todel as $show){
		$delquery->bindParam(":id",$show);
		$result[]=$delquery->execute();
	}
    $delquery=$dbhandle->prepare("delete from shows where id = :id");
    foreach($todel as $show){
		$delquery->bindParam(':id',$show);
		$result[]=$delquery->execute();
    }

	foreach($result as $check){
		if(!$check){
			$dbhandle->rollBack();
			return $check;
		}
	}
	return $dbhandle->commit();
}

function addappt($toadd){
	$error=false;
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare("insert into appointments (actorid,showid,start,end,note)
		values (:actorid,:showid,:start,:end,:note)");
	foreach($toadd as $appt){
		$query->bindParam(':actorid',$appt["actorid"]);
		$query->bindParam(':showid',$appt["showid"]);
		$query->bindParam(':start',$appt["start"]);
		$query->bindParam(':end',$appt["end"]);
		$query->bindParam(':note',$appt["note"]);
		$queryresult=$query->execute();
		if($queryresult<1){$error=true;}
		else{$results[]=$queryresult;}
	}
	dbdisconnect($dbhandle);
	if($error){return $error;}
	else{return array_sum($results);}
}

function modappt($toadd){
	$error=false;
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare("update appointments set actorid=:actorid,showid=:showid,start=:start,end=:end,note=:note
		where apptid=:apptid");
	foreach($toadd as $appt){
		$query->bindParam(':apptid',$appt["apptid"]);
		$query->bindParam(':actorid',$appt["actorid"]);
		$query->bindParam(':showid',$appt["showid"]);
		$query->bindParam(':start',$appt["start"]);
		$query->bindParam(':end',$appt["end"]);
		$query->bindParam(':note',$appt["note"]);
		$queryresult=$query->execute();
		if($queryresult<1){$error=true;}
		else{$results[]=$queryresult;}
	}
	dbdisconnect($dbhandle);
	if($error){return $error;}
	else{return array_sum($results);}
}

function getappt($commands=null){
	$querystring="select appt.apptid as apptid,appt.actorid as actorid,shows.title as title, appt.showid as showid,
					appt.start as start,appt.end as end,appt.note as note, actors.fname as fname,
					actors.lname as lname, actors.phone as phone, casts.partname as partname, casts.priority as priority
			from appointments as appt
			inner join casts
			using (showid,actorid)
			inner join shows
			on appt.showid=shows.id
			inner join actors
			on appt.actorid=actors.id";
	if(is_array($commands)){
		if(isset($commands["sort"])){
			$sort="";
			foreach($commands["sort"] as $sortby){
				$sort.="$sortby ";
			}
			$sort=trim($sort);
			$sort=str_replace(" ",",",$sort);
		}
		if(isset($commands["constraint"]) && is_array($commands["constraint"])){
			$toxic=false;
			foreach($commands["constraint"] as $constraint){
				//************************************************************
				if(!is_array($constraint)){return false;}
				//************************************************************
			}
			if(!$toxic){
				$constraints="";
				for($i=0;$i<count($commands["constraint"]);$i++){
					$constraints.=" ".$commands["constraint"][$i]["col"]." ".
							$commands["constraint"][$i]["op"]." :value$i";
					if($commands["constraint"][$i]["op"]=="between"){
						$constraints.=" and :value2$i";
					}
					if($i<(count($commands["constraint"])-1)){
						$constraints.=" and";
					}
				}
			}
		}

		
		if(isset($commands["constraint"])){
			$querystring.=" where ".$constraints;
		}
		if(isset($sort)){$querystring.=" order by ".$sort;}
	}
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare($querystring);
	if(isset($commands["constraint"])){
		//echo "binding values<br/>";
		for($i=0;$i<(count($commands["constraint"]));$i++){
			//echo "binding value $i to ".$commands["constraint"][$i]["value"]."<br/>";
			if($commands["constraint"][$i]["op"]=="between"){
				$query->bindParam(":value$i",$commands["constraint"][$i]["value"][0]);
				$query->bindParam(":value2$i",$commands["constraint"][$i]["value"][1]);
			}else{
				$query->bindParam(":value$i",$commands["constraint"][$i]["value"]);
			}
		}
	}
	//echo "$query->queryString" . "<br/>";
	$query->execute();
	$result=$query->fetchAll();
	return $result;
}

function isavailable($actor,$currenttime){
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare('select id from availability where id=:id and time=:time and day=:day');
	$query->bindParam(":id",$actor);
	$query->bindParam(":time",$currenttime->format('Hi'));
	$query->bindParam(":day",$currenttime->format('D'));
	$query->execute();
	$result=$query->fetchAll();
	dbdisconnect($dbhandle);
	if(count($result) > 0){
		return true;
	}else{
		return false;
	}
}

function listavailable($currenttime){
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare("
		select showid,actorid,partname,fname,lname,title
		from casts
		inner join actors on actors.id=actorid
		inner join shows on (showid=shows.id)
		inner join availability on actorid=availability.id
		where time=:time and day=:day
		and 0 = (
			select count(actorid)
			from appointments
			where start<=:datetime and end>:datetime and casts.actorid=actorid)");
	$query->bindParam(':time',$currenttime->format("Hi"));
	$query->bindParam(':day',$currenttime->format("D"));
	$query->bindParam(':datetime',$currenttime->format("Y-m-d Hi"));
	$query->execute();
	$results=$query->fetchAll();
	dbdisconnect($dbhandle);
	return $results;
}

function isshopopen($currenttime){
	$dbhandle=dbconnect();
	$query=$dbhandle->prepare("select count(*) from actors where staff='true'");
	$query->execute();
	$numberofstaff=$query->fetch();
	$query=$dbhandle->prepare("select count(*) from actors as a
							inner join  availability as b on a.id=b.id
							where a.staff='true'
							and b.'time'=:time and b.day=:day");
	$query->bindParam(":time",$currenttime->format("Hi"));
	$query->bindParam(":day",$currenttime->format("D"));
	$query->execute();
	$staffavailable=$query->fetch();
	if($numberofstaff[0]==$staffavailable[0])
	{
		dbdisconnect($dbhandle);
		return true;
	}else{
		dbdisconnect($dbhandle);
		return false;
	}
}

function processpostavail($postdata){
	//process incoming availability form data
	$currenttime=new DateTime(WEEKSTART . " " . DAYSTART);
	for($i=0;$i<WORKDAYS;$i++){//six work days, so six iterations
		if(is_array($postdata[$currenttime->format('D')])){ //see if we have any availability data for the current day
			$avail[$currenttime->format('D')]=$postdata[$currenttime->format('D')];//copy the day's availibility data array
		}
		$currenttime->modify("+1 day");//move up to the next day
	}
	unset($currenttime);
	return $avail;
}



/* **********************************************************************
 * *****************  AUTH FUNCTIONS  ***********************************
 * **********************************************************************/

/* check if a particular session id is a valid session */
function loggedin($session)
{
    $username=session_query($session);
    return $username;
}

/* check username validity */
function isvalid($username)
{

}

/* get username's group membership (returns array, primary group first) */
function getgroup($username)
{

}

/* log somebody in, create session */
function login($username,$password)
{

}

/* log somebody out, end session */
function logout($username)
{

}

?>
